@@ -37,9 +37,11 @@ pub fn scroll_paper(context: WidgetContext) -> WidgetNode {
     } = context;
     unpack_named_slots!(named_slots => {content, scrollbars});
 
+    let inner_props = props.clone().without::<ContentBoxItemLayout>();
+
     widget! {
         (#{key} | {idref.cloned()} paper: {props.clone()} [
-            (#{"scroll"} nav_scroll_box: {props.clone()} {
+            (#{"scroll"} nav_scroll_box: {inner_props} {
                 content = {content}
                 scrollbars = {scrollbars}
             })
